@@ -54,6 +54,8 @@ ScriptThread(interp, 0), XMLStream()
 	lang = NULL;
 	img = NULL;
 	ip = ipt;
+	bcount = 0;
+	bnext = NULL;
 }
 
 ParseThread::~ParseThread()
@@ -729,9 +731,11 @@ void ParseThread::startBlock(const char **attrib)
 	const char *clear = NULL;
 	const char *args[3];
 	const char *vargs[3];
+	char nbuf[10];
 
 	memset(vargs, 0, sizeof(vargs));
 
+	bnext = NULL;
 	while(attrib && *attrib)
 	{
 		if(!stricmp(*attrib, "label") || !stricmp(*attrib, "name"))
@@ -740,6 +744,8 @@ void ParseThread::startBlock(const char **attrib)
 			repeat = *(++attrib);
 		else if(!stricmp(*attrib, "cleardigits"))
 			clear = *(++attrib);
+		else if(!stricmp(*attrib, "next"))
+			bnext = *(++attrib);
 		else
 			++attrib;
 		++attrib;
@@ -748,6 +754,12 @@ void ParseThread::startBlock(const char **attrib)
 	if(name && *name == '#')
 		++name;
 
+	if(!name && bcount++)
+	{
+		snprintf(nbuf, sizeof(nbuf), "%ud", bcount);
+		name = nbuf;
+	}
+
 	if(name)
 	{
 		img->getCompile(&block, img->dupString(name));
@@ -772,10 +784,53 @@ void ParseThread::startBlock(const char **attrib)
 	
 void ParseThread::endBlock(void)
 {
+	char *p, *q;
+	const char *label;
+	const char *args[10];
+
 	current->trap = 0;
 	if(current->repeated)
 		img->addCompile(current, 0, "loop", NULL);
 	current->repeated = false;
+	if(bnext)
+	{
+		if(!strchr(bnext, '/'))
+		{
+			if(*bnext == '#')
+				++bnext;
+			args[0] = bnext;
+			args[1] = NULL;
+			img->addCompile(current, 0, "startxml", args);
+		}
+		else
+		{
+			label = NULL;
+			p = strchr(bnext, '#');
+			if(p)
+			{
+				*p = 0;
+				label = img->dupString((const char *)(p + 1));
+				q = strchr(label, '?');
+				if(q)
+				{
+					*(q++) = 0;
+					strcpy(p, q);
+				}
+			}
+			args[0] = "definitions::xml-parse";
+			args[1] = "=from";
+			args[2] = bnext;
+			args[3] = NULL;
+			if(label)
+			{
+				args[3] = "=goto";
+				args[4] = label;
+				args[5] = NULL;
+			}
+			img->addCompile(current, 0, "call", args);
+		}
+		bnext = NULL;
+	}
 	if(current != &main)
 	{
 		img->postCompile(current);
