@@ -72,7 +72,13 @@ BayonneBinder("ivrscript1")
 	slog.info("binding ivrscript...");
 	PersistProperty::load();
 
-	ScriptInterp::addConditional("key", &testKey); 
+	ScriptInterp::addConditional("key", &testKey);
+	ScriptInterp::addConditional("registered", &testRegistered);
+	ScriptInterp::addConditional("available", &testAvailable);
+	ScriptInterp::addConditional("extension", &testExternal);
+	ScriptInterp::addConditional("external", &testExternal);
+	ScriptInterp::addConditional("reachable", &testReachable);
+
 	Bayonne::use_prefix = true;
 	Bayonne::use_macros = true;
 	Bayonne::use_merge = false;
@@ -336,6 +342,93 @@ bool Binder::testKey(ScriptInterp *interp, const char *v)
 {
         return PersistProperty::test(v);
 }
-  
+
+bool Binder::testRegistered(ScriptInterp *inter, const char *v)
+{
+	BayonneDriver *d = NULL;
+	char vbuf[8];
+	char *p;
+
+	setString(vbuf, sizeof(vbuf), v);
+	p = strchr(v, ':');
+	if(p)
+	{
+		*p = 0;
+		v = (const char *)++p;
+		d = BayonneDriver::get(vbuf);
+	}
+	if(!d)
+		d = BayonneDriver::getProtocol();
+	if(!d)
+		return false;
+
+	return d->isRegistered(v);
+}
+
+bool Binder::testExternal(ScriptInterp *interp, const char *v)
+{
+	BayonneDriver *d = NULL;
+	char vbuf[8];
+	char *p;
+
+	setString(vbuf, sizeof(vbuf), v);
+	p = strchr(v, ':');
+	if(p)
+	{
+		*p = 0;
+		v = (const char *)++p;
+		d = BayonneDriver::get(vbuf);
+	}
+	if(!d)
+		d = BayonneDriver::getProtocol();
+	if(!d)
+		return false;
+
+	return d->isExternal(v);
+}
+
+bool Binder::testAvailable(ScriptInterp *inter, const char *v)
+{
+	BayonneDriver *d = NULL;
+	char vbuf[8];
+	char *p;
+
+	setString(vbuf, sizeof(vbuf), v);
+	p = strchr(v, ':');
+	if(p)
+	{
+		*p = 0;
+		v = (const char *)++p;
+		d = BayonneDriver::get(vbuf);
+	}
+	if(!d)
+		d = BayonneDriver::getProtocol();
+	if(!d)
+		return false;
+
+	return d->isAvailable(v);
+}  
+
+bool Binder::testReachable(ScriptInterp *inter, const char *v)
+{
+	BayonneDriver *d = NULL;
+	char vbuf[8];
+	char *p;
+
+	setString(vbuf, sizeof(vbuf), v);
+	p = strchr(v, ':');
+	if(p)
+	{
+		*p = 0;
+		v = (const char *)++p;
+		d = BayonneDriver::get(vbuf);
+	}
+	if(!d)
+		d = BayonneDriver::getProtocol();
+	if(!d)
+		return false;
+
+	return d->isReachable(v);
+}  
 
 } // end namespace
