@@ -549,10 +549,7 @@ ScriptCompiler *Bayonne::reload(void)
 	compile_count = 0;
 
 	reloading.writeLock();
-	img = new ScriptCompiler(server, "/bayonne/server/config");
-	if(getUserdata())
-		img->loadPrefix("config", "~bayonne/config");
-
+	img = BayonneBinder::getCompiler();
 	img->setValue("text.cr", "\r");
 	img->setValue("text.nl", "\n");
 	img->setValue("text.dl", "\n\n");
@@ -746,8 +743,13 @@ BayonneSession *Bayonne::startDialing(const char *dial, const char *name, const
 
 trunking:
 	img = useImage();
-	snprintf(buffer, sizeof(buffer), "select.%s", name);
-	scr = (Name *)img->getPointer(buffer);
+	if(strstr(name, "::"))
+		scr = img->getScript(name);
+	else
+	{
+		snprintf(buffer, sizeof(buffer), "select.%s", name);
+		scr = (Name *)img->getPointer(buffer);
+	}
 
 	if(!scr || !scr->select || scr->access != scrPUBLIC)
 	{
@@ -809,8 +811,13 @@ trunking:
 
 protocol:	
 	img = useImage();
-	snprintf(buffer, sizeof(buffer), "start-%s.%s", d->getName(), name);
-	scr = (Name *)img->getPointer(buffer);
+	if(strstr(name, "::"))
+		scr = img->getScript(name);
+	else
+	{
+		snprintf(buffer, sizeof(buffer), "start-%s.%s", d->getName(), name);
+		scr = (Name *)img->getPointer(buffer);
+	}
 
 	if(!scr || scr->access != scrPUBLIC)
 	{
