@@ -20,6 +20,67 @@ namespace server {
 using namespace ost;
 using namespace std;
 
+bool Methods::scrSay(void)
+{
+	char buf[256];
+	Name *tts;
+	Name *scr = getName();
+	Line *line = getLine();
+	const char *ext = getKeyword("extension");
+	const char *prefix = getKeyword("prefix");
+	const char *voice = getKeyword("voice");
+	const char *file = getKeyword("file");
+	const char *opt;
+	unsigned len = 0;
+
+	snprintf(buf, sizeof(buf), "definitions::tts-%s", 
+		keylibexec.getLast("tts"));
+
+	tts = getScript(buf);
+	if(!tts)
+	{
+		error("tts-missing");
+		return true;
+	}
+
+	if(!voice)
+		voice = keylibexec.getLast("voice");
+
+	while((NULL != (opt = getValue(NULL))) && (len < (sizeof(buf) - 2)))
+	{
+		setString(buf + len, sizeof(buf) - len, opt);
+		len += strlen(opt);
+	}		
+
+	if(!push())
+	{
+		error("tts-overflow");
+		return true;
+	}
+
+	frame[stack].tranflag = true;
+	frame[stack].index = 0;
+	frame[stack].caseflag = false;
+	frame[stack].local = new ScriptSymbols();
+	frame[stack].script = tts;
+	frame[stack].line = frame[stack].first = tts->first;
+	frame[stack].mask = scr->mask & line->mask;
+	frame[stack].mask |= tts->mask;
+	updated = true;
+
+
+	setConst("voice", voice);
+	setConst("text", buf);
+	if(prefix)
+		setConst("prefix", prefix);
+	if(ext)
+		setConst("extension", ext);
+	if(file)
+		setConst("file", file);
+	setConst("limit", keylibexec.getLast("ttslimit"));
+	return true;
+}
+
 bool Methods::scrTransfer(void)
 {
 	char nbuf[MAX_PATHNAME];
@@ -199,12 +260,15 @@ bool Methods::scrTonegen(void)
 bool Methods::scrTone(void)
 {
 	Line *line = getLine();
-	const char *name = line->cmd;
+	const char *name = getKeyword("name");
 	const char *loc = getKeyword("location");
 	const char *cp = getKeyword("level");
 	TelTone::tonekey_t *key;
 	Audio::Level level = 26000;
 
+	if(!name)
+		name = line->cmd;
+
 	if(cp)
 		level = atoi(cp);
 
